summaryrefslogtreecommitdiffstats
path: root/chrome/test/automation/automation_proxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/test/automation/automation_proxy.h')
-rw-r--r--chrome/test/automation/automation_proxy.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/chrome/test/automation/automation_proxy.h b/chrome/test/automation/automation_proxy.h
index 788a3dc..3dfb7f1 100644
--- a/chrome/test/automation/automation_proxy.h
+++ b/chrome/test/automation/automation_proxy.h
@@ -153,19 +153,21 @@ class AutomationProxy : public IPC::Listener, public AutomationMessageSender {
int timeout_ms,
std::string* response) WARN_UNUSED_RESULT;
// Begin tracing specified categories on the browser instance. Blocks until
// browser acknowledges that tracing has begun (or failed if false is
// returned). |categories| is a comma-delimited list of category wildcards.
// A category can have an optional '-' prefix to make it an excluded category.
// Either all categories must be included or all must be excluded.
//
// Example: BeginTracing("test_MyTest*");
// Example: BeginTracing("test_MyTest*,test_OtherStuff");
// Example: BeginTracing("-excluded_category1,-excluded_category2");
//
// See base/event_trace.h for documentation of included and excluded
- // categories.
- bool BeginTracing(const std::string& categories) WARN_UNUSED_RESULT;
+ // category_patterns.
+ bool BeginTracing(const std::string& category_patterns) WARN_UNUSED_RESULT;
// End trace and collect the trace output as a json string.
bool EndTracing(std::string* json_trace_output) WARN_UNUSED_RESULT;
@@ -153,19 +153,21 @@ class AutomationProxy : public IPC::Listener, public AutomationMessageSender {
int timeout_ms,
std::string* response) WARN_UNUSED_RESULT;
- // Begin tracing specified categories on the browser instance. Blocks until
- // browser acknowledges that tracing has begun (or failed if false is
- // returned). |categories| is a comma-delimited list of category wildcards.
- // A category can have an optional '-' prefix to make it an excluded category.
- // Either all categories must be included or all must be excluded.
+ // Begin tracing specified category_patterns on the browser instance. Blocks
+ // until browser acknowledges that tracing has begun (or failed if false is
+ // returned). |category_patterns| is a comma-delimited list of category
+ // wildcards.
+ // A category pattern can have an optional '-' prefix to exclude category
+ // groups that contain matching category.
+ // Either all category_patterns must be included or all must be excluded.
//
// Example: BeginTracing("test_MyTest*");